#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable

from src.calculator import Calculator
from src.factorial import Factorial
from src.primes import Primes
from src.fib import Fib


class TddInPythonExample(unittest.TestCase):

    # CALCULATOR #

    def test_calculator_add_method(self):
        calc = Calculator()
        result = calc.add(2, 2)
        self.assertEqual(4, result)

    def test_calculator_sub_method(self):
        calc = Calculator()
        result = calc.sub(2, 2)
        self.assertEqual(0, result)

    def test_calculator_prod_method(self):
        calc = Calculator()
        result = calc.prod(2, 2)
        self.assertEqual(4, result)

    def test_calculator_div_method(self):
        calc = Calculator()
        result = calc.div(2, 2)
        self.assertEqual(1, result)

    def test_calculator_prodUsingAdd_method(self):
        calc = Calculator()
        result = calc.prodUsingAdd(5, 4)
        self.assertEqual(20, result)

    # FACTORIAL #

    def test_factorial_fac2_method(self):
        f = Factorial()
        result = f.fac(2)
        self.assertEqual(2, result)

    def test_factorial_fac3_method(self):
        f = Factorial()
        result = f.fac(3)
        self.assertEqual(6, result)

    def test_factorial_fac4_method(self):
        f = Factorial()
        result = f.fac(4)
        self.assertEqual(24, result)

    # FIBONACCI #

    def test_fib_fib2_method(self):
        f = Fib()
        result = f.fib(2)
        self.assertEqual([1, 1], result)

    def test_fib_fib3_method(self):
        f = Fib()
        result = f.fib(3)
        self.assertEqual([1, 1, 2, 3, 5], result)

    def test_fib_fib4_method(self):
        f = Fib()
        result = f.fib(4)
        self.assertEqual([1, 1, 2, 3, 5, 8], result)

    # PRIMES #

    def test_primes_divisible_method(self):
        p = Primes()
        result = p.divisible(4, 2)
        self.assertEqual(result, True)

    def test_primes_generateList_method(self):
        p = Primes()
        result = p.generateList(2, 11)
        self.assertEqual([2, 3, 4, 5, 6, 7, 8, 9, 10, 11], result)

    def test_primes_dividers_method(self):
        p = Primes()
        result = p.dividers(4)
        self.assertEqual([1, 2, 4], result)

    def test_primes_primes_method(self):
        p = Primes()
        result = p.primes(4)
        self.assertEqual([1, 2, 3], result)


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python3
# -*- coding: utf-8 -*-
#  Copyright (C) 2022 David Arroyo Menendez

#  Author: David Arroyo Menendez <davidam@gmail.com>
#  Maintainer: David Arroyo Menendez <davidam@gmail.com>
#  This file is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3, or (at your option)
#  any later version.
# 
#  This file is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with DameBasics; see the file GPL.txt.  If not, write to
#  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, 
#  Boston, MA 02110-1301 USA,

import unittest
import collections
collections.Callable = collections.abc.Callable

from pprint import pprint

class TddInPythonExample(unittest.TestCase):

    def test_files_write_returns_correct_result(self):
        fo = open("files/tmp.txt", "w")
        fo.write("Gora python\n");
        fo.close()
        with open('files/tmp.txt', encoding='utf8') as f:
            text = f.read().strip()
        self.assertEqual(text, "Gora python")

    def test_files_write_lines_returns_correct_result(self):
        file = open("files/tmp2.txt", "w")
        file.write("This is a test\n")
        file.write("To add more lines.\n")
        lines_of_text = ["One line of text here\n", "and another line here\n", "and yet another here\n", "and so on and so forth\n"]
        file.writelines(lines_of_text)
        file.close()
        with open('files/tmp2.txt', encoding='utf8') as f:
            text = f.read().strip()
        self.assertEqual(text, "This is a test\nTo add more lines.\nOne line of text here\nand another line here\nand yet another here\nand so on and so forth")

    def test_files_readline_returns_correct_result(self):
        fo = open("files/tmp.txt", "r+")
        char = fo.readline(1)
        self.assertEqual(char, "G")
        fo.seek(1)
        line = fo.readline()
        self.assertEqual(line, "ora python\n")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable

from pprint import pprint


class TddInPythonExample(unittest.TestCase):

    def test_tuple_set_method_returns_correct_result(self):
        a = (1, 1, 2, 2, 3, 3)
        tsa = tuple(set(a))
        self.assertEqual((1, 2, 3), tsa)
        self.assertTrue(isinstance(tsa, tuple))

    def test_tuple_join_method_returns_correct_result(self):
        a = ('2',)
        b = 'z'
        new = a + (b,)
        self.assertEqual(('2', 'z'), new)
        self.assertTrue(isinstance(new, tuple))





#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2018  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gnu.org>
# Maintainer: David Arroyo Menéndez <davidam@gnu.org>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

class Fraction(object):

    def __init__(self, n, d):
        self.numerator, self.denominator = self.reduce(n, d)

    @staticmethod
    def gcd(a, b):
        while b != 0:
            a, b = b, a % b
        return a

    @classmethod
    def reduce(cls, n1, n2):
        g = cls.gcd(n1, n2)
        return (n1 // g, n2 // g)

    def __str__(self):
        return str(self.numerator) + '/' + str(self.denominator)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
import datetime
from datetime import timedelta
from pprint import pprint
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable


class TddInPythonExample(unittest.TestCase):

    def test_datetime_date_method_returns_correct_result(self):
        mydate = datetime.date(1943, 3, 13)  # year, month, day
        self.assertEqual(mydate.strftime("%A"), "Saturday")
        self.assertEqual(mydate.strftime("%B"), "March")
        self.assertTrue(isinstance(mydate, datetime.date))

    def test_datetime_timedelta_method_returns_correct_result(self):
        seconds = 153.1205153
        d = timedelta(seconds)
#        self.assertEqual("153 days, 2:53:32.521920", d)
        self.assertEqual(d.days, 153)
        self.assertEqual(d.seconds, 10412)

    def test_datetime_comparing_methods_returns_correct_result(self):
        t1 = datetime.time(12, 55, 0)
        t2 = datetime.time(13, 5, 0)
        self.assertTrue(t1 < t2)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
from pprint import pprint
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable


class TddInPythonExample(unittest.TestCase):

    def test_list_append_method_returns_correct_result(self):
        mylist = []
        mylist.append(1)
        mylist.append(2)
        mylist.append(3)

        self.assertEqual(1, mylist[0])
        self.assertEqual(2, mylist[1])
        self.assertEqual(3, mylist[2])
        self.assertTrue(isinstance(mylist, list))

    def test_list_methods_returns_correct_result(self):
        li = ["a", "b", "mpilgrim", "z", "example"]
        self.assertEqual(li[0], "a")
        self.assertEqual(li[0], "a")
        li.extend(["two", "elements"])
        self.assertEqual(li[-1], "elements")
        li.insert(2, "new")
        self.assertEqual(li[2], "new")
        self.assertEqual(5, li.index("example"))
        li.remove("example")
        self.assertEqual(["a", "b", "new", "mpilgrim",
                          "z", "two", "elements"],
                         li)
        self.assertTrue(isinstance(li, list))


    def test_list_union_method_returns_correct_result(self):
        lista = ['a', 'b', 'mpilgrim']
        lista = lista + ['example', 'new']
        lista += ['two']
        self.assertEqual(lista, ['a', 'b', 'mpilgrim',
                                 'example', 'new', 'two'])
        self.assertTrue(isinstance(lista, list))

    def test_list_sort_method_returns_correct_result(self):
        milista = ['This', 'used', 'to', 'be', 'a',
                   'Whopping', 'Great', 'sentence']
        milista2 = sorted(milista, key=str.lower)
        self.assertEqual(milista2, ['a', 'be', 'Great',
                                    'sentence', 'This',
                                    'to', 'used', 'Whopping'])
        self.assertTrue(isinstance(milista2, list))

    def test_list_lambda_method_returns_correct_result(self):
        l1 = list(map(lambda x: x**2, range(10)))
        l2 = [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
        self.assertEqual(l1, l2)
        self.assertTrue(isinstance(l1, list))
        self.assertTrue(isinstance(l2, list))



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
from pprint import pprint
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable


class TddInPythonExample(unittest.TestCase):

    def test_conditional_method_returns_correct_result(self):
        x = 2
        if x < 0:
            x = 0
            x = 'Negative changed to zero'
        elif x == 0:
            x = 'Zero'
        elif x == 1:
            x = 'Single'
        else:
            x = 'More than one'

        self.assertEqual(x, 'More than one')

    def test_for_method_returns_correct_result(self):
        words = ['cat', 'window', 'defenestrate']
        string = ""
        for w in words:
            string = string + w + "," + str(len(w)) + ";"

        self.assertEqual("cat,3;window,6;defenestrate,12;", string)

    def test_zip_method_returns_correct_result(self):
        v = [1, 2, 3]
        w = [1, 2, 3]
        z = []
        for v_i, w_i in zip(v, w):
            z = z + [v_i + w_i]
        self.assertEqual(z, [2, 4, 6])

    def test_enumerate_method_returns_correct_result(self):
        words = ['cat', 'window', 'defenestrate']
        string = ""
        for i, w in enumerate(words):
            string = string + str(i) + w

        self.assertEqual("0cat1window2defenestrate", string)

    def test_range_method_returns_correct_result(self):
        words = ['cat', 'window', 'defenestrate']
        string = ""
        for i in range(1, 10):
            string = string + str(i)

        self.assertEqual("123456789", string)

    def test_format_method_returns_correct_result(self):
        string1 = ','.join('{}'.format(i) for i in range(1, 10, 4))
        self.assertEqual("1,5,9", string1)
        string2 = ','.join('{},{}'.format(i, i + 1) for i in range(1, 30, 4))
        self.assertEqual("1,2,5,6,9,10,13,14,17,18,21,22,25,26,29,30", string2)

    def test_while_method_returns_correct_result(self):
        vector = [1, 2, 3, 4, 5]
        i = 0
        string = ""
        while (i < len(vector)):
            string = string + str(vector[i])
            i = i + 1
        self.assertEqual(string, "12345")



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with damebasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
import collections
collections.Callable = collections.abc.Callable

from pprint import pprint


class TddInPythonExample(unittest.TestCase):

    def test_arithmetics_calculator_returns_correct_result(self):
        mysum = 2 + 2
        sumres = 4
        self.assertEqual(mysum, sumres)
        myminus = 3 - 2
        minusres = 1
        self.assertEqual(myminus, minusres)
        mymul = 3 * 2
        mulres = 6
        self.assertEqual(mymul, mulres)
        mydiv = 4 / 2
        divres = 2
        self.assertEqual(mydiv, divres)
        mypow = pow(2, 3)
        powres = 8
        self.assertEqual(mypow, powres)
        mymod = 5 % 2
        modres = 1
        self.assertEqual(mymod, modres)

    def test_arithmetics_round_returns_correct_result(self):
        myround1 = round(3.6)
        round1res = 4
        self.assertEqual(round1res, myround1)
        myround2 = round(3.1459, 2)
        round2res = 3.15
        self.assertEqual(round2res, myround2)



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (C) 2021  David Arroyo Menéndez

# Author: David Arroyo Menéndez <davidam@gmail.com>
# Maintainer: David Arroyo Menéndez <davidam@gmail.com>

# This file is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.

# This file is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with DameBasics; see the file LICENSE.  If not, write to
# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
# Boston, MA 02110-1301 USA,

import unittest
import socket
from pprint import pprint
# fix for MacOS using nose
import collections
collections.Callable = collections.abc.Callable


class TddInPythonExample(unittest.TestCase):

    def test_network_socket_method_returns_correct_result(self):
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.connect(("www.python.org", 80))
        self.assertTrue("<socket.socket" in str(s))

    def test_network_socket_get_method_returns_correct_result(self):
        self.assertTrue(socket.gethostbyname(socket.gethostname()), "127.0.0.1")
        self.assertTrue(socket.gethostbyaddr('127.0.0.1'), ('localhost', [], ['127.0.0.1']))
        proto = "tcp"
        self.assertEqual(socket.getservbyname("ftp",proto), 21)
        self.assertEqual(socket.getservbyname("http",proto), 80)
        self.assertEqual(socket.getservbyname("https",proto), 443)
        self.assertEqual(socket.getservbyport(21,proto), "ftp")
        self.assertEqual(socket.getservbyport(80,proto), "http")
        self.assertEqual(socket.getservbyport(443,proto), "https")

    def test_network_startswith_method_returns_correct_result(self):
        my_ip = socket.gethostbyname(socket.gethostname())
        self.assertTrue(my_ip.startswith('127.0.'))
